@@ -1,22 +1,24 @@
 import os
 from pathlib import Path
-from typing import Generator, Optional
+from typing import Any, Generator, Optional
 from unittest.mock import Mock, patch
 
+from click.testing import Result
 from pytest import FixtureRequest, fixture
 from typer.testing import CliRunner
 
+from tests.commands.helpers import Runner
+
 
 @fixture
-def cli_runner() -> CliRunner:
-    return CliRunner(mix_stderr=False)
-
-
-@fixture(autouse=True)
-def test_data_dir(tmp_path: Path) -> Path:
-    data_dir = tmp_path
-    os.environ['XDG_DATA_HOME'] = str(data_dir)
-    return data_dir
+def runner(mock_copy_save_file: Mock) -> Runner:
+    def cli_runner(*args: Any, **kwargs: Any) -> Result:
+        return CliRunner(mix_stderr=False).invoke(
+            *args,
+            obj={'copy_save_file': mock_copy_save_file},
+            **kwargs,
+        )
+    return cli_runner
 
 
 @fixture(autouse=True)
@@ -40,3 +42,8 @@ def mock_draw(request: FixtureRequest) \
     else:
         with patch('route_tracker.io.draw') as mock:
             yield mock
+
+
+@fixture
+def mock_copy_save_file() -> Mock:
+    return Mock()
